
/* **************************************************************************

  $Archive: /njcl_v2/src/com/novell/service/jncpv2/cal/DeviceAccessJNI.java $
  $Revision: 3 $
  $Modtime: 1/24/00 7:59p $
 
  Copyright (c) 1998 Novell, Inc.  All Rights Reserved.

  THIS WORK IS  SUBJECT  TO  U.S.  AND  INTERNATIONAL  COPYRIGHT  LAWS  AND
  TREATIES.   NO  PART  OF  THIS  WORK MAY BE  USED,  PRACTICED,  PERFORMED
  COPIED, DISTRIBUTED, REVISED, MODIFIED, TRANSLATED,  ABRIDGED, CONDENSED,
  EXPANDED,  COLLECTED,  COMPILED,  LINKED,  RECAST, TRANSFORMED OR ADAPTED
  WITHOUT THE PRIOR WRITTEN CONSENT OF NOVELL, INC. ANY USE OR EXPLOITATION
  OF THIS WORK WITHOUT AUTHORIZATION COULD SUBJECT THE PERPETRATOR TO
  CRIMINAL AND CIVIL LIABILITY.

****************************************************************************/


package com.novell.service.jncpv2.cal;


import java.util.*;
import com.novell.java.lang.*;
import com.novell.service.file.nw.*;
import com.novell.service.server.*;
import com.novell.service.ncpext.*;
import com.novell.service.file.nw.calls.*;
import com.novell.service.qms.*;


/** @internal
 * Native method declarations
 */
public class DeviceAccessJNI
{
   public static native int JDAClose (
         /*in*/   int                     handle);

   public static native int JDAFlush (
         /*in*/   int                     handle);

   public static native int JDAGetLength (
         /*in*/   int                        handle,
         /*out*/  int[]                      length);

   public static native int JDASetLength (
         /*in*/   int                        handle,
         /*in*/   int                        length);

   public static native int JDAGetPosition (
         /*in*/   int                           handle,
         /*out*/  int[]                         position);

   public static native int JDASetPosition (
         /*in*/   int                           handle,
         /*in*/   int                           mode,
         /*in*/   int                           position);

   public static native int JDARead (
         /*in*/   int                  handle,
         /*in*/   int                  length,
         /*out*/  byte[][]             buffer);

   public static native int JDAWrite (
         /*in*/   int                     handle,
         /*in*/   byte[]                  buffer);

} /* DeviceAccessJNI */


